//-----------------------------------------------------------------------------
// Copyright  Micromega Corporation 2005-2008. All rights reserved.
//
// @file   fpu.h
// @target Atmel AVR WinAVR compiler
//
// Defines uM-FPU V3 opcodes, matrix operations and FFT operations.
// Functions prototypes for C calls to fpu.S
//
// @author Cam Thompson, Micromega Corporation
// @version
//	August 31, 2007
//	- updated for uM-FPU V3.1
//	November 17, 2006
//	- original version
//
//-----------------------------------------------------------------------------

#include "fops.h"				// define all opcodes

//-------------------- FPU status bits ----------------------------------------

#define STATUS_ZERO	0x01		// Zero status bit
#define STATUS_SIGN	0x02		// Sign status bit
#define STATUS_NAN	0x04		// NaN (Not-a-Number) status bit
#define STATUS_INF	0x08		// Infinity status bit

//-------------------- fpu_hw.S prototypes ---------------------------------------

char fpu_reset(void);
void fpu_wait(void);

void fpu_write(char bval1);
void fpu_write2(char bval1, char bval2);
void fpu_write3(char bval1, char bval2, char bval3);
void fpu_write4(char bval1, char bval2, char bval3, char bval4);
void fpu_writeWord(int wval);
void fpu_writeFloat(float fval);
void fpu_writeLong(long lval);
void fpu_writeString(char *s);
void fpu_writeFloatReg(float fval, char reg);
void fpu_writeLongReg(long lval, char reg);
void fpu_wrblk(char cnt, float *ptr);

char fpu_read(void);
int fpu_readWord(void);
float fpu_readFloat(void);
long fpu_readLong(void);
void fpu_readString(char *s);
float fpu_readFloatReg(char reg);
long fpu_readLongReg(char reg);
char fpu_readStatus(void);
void fpu_rdblk(char cnt, float *ptr);

void fpu_fcall(char func);

void fpu_readDelay(void);
void _loadRegA(void);

//-------------------- fpuPrint.c prototypes ----------------------------------

void print_version(void);
void print_long(char format);
void print_float(char format);
void print_floatVal(float fnum, char format);
void print_fpuString(char opcode);
void print_CRLF(void);



