//=============================================================================
// Copyright  Micromega Corporation 2005-2008. All rights reserved.
//
// @file	fpuPrint.c
// @target	Atmel WinAVR C compiler
//
// Low-level UART routine.
//
// @author	Cam Thompson, Micromega Corporation
// @version
//	September 1, 2007
//	- original version
//=============================================================================

#include <avr/io.h>
#include <stdio.h>
#include "fpu.h"

//------------------- print_version -------------------------------------------

void print_version(void) {

	fpu_write(VERSION);
	print_fpuString(READSTR);
}

//------------------- print_floatVal ------------------------------------------

void print_floatVal(float fnum, char format) {
	_loadRegA();
	print_float(format);
	fpu_write(RIGHT);
}

//------------------- print_float ---------------------------------------------

void print_float(char format) {

	fpu_write2(FTOA, format);
	print_fpuString(READSTR);
}

//------------------- print_longVal ------------------------------------------

void print_longVal(float fnum, char format) {
	_loadRegA();
	print_long(format);
	fpu_write(RIGHT);
}

//------------------- print_long ----------------------------------------------

void print_long(char format) {

	fpu_write2(LTOA, format);
	print_fpuString(READSTR);
}

//------------------- print_fpuString -----------------------------------------

void print_fpuString(char opcode) {
	char bval;

	if (opcode != (char) READSEL) opcode = READSTR;
	fpu_wait();
	fpu_write(opcode);
	fpu_readDelay();

	while (1) {
		bval = fpu_read();
		if (bval == 0) break;
		putchar(bval);
	} 
}

//------------------- print_CRLF ----------------------------------------------

void print_CRLF(void) {

	putchar('\r');
	putchar('\n');
}
