//=============================================================================
// Copyright  Micromega Corporation 2005-2008. All rights reserved.
//
// @file	fpu_i2c.h
// @target	Atmel WinAVR C compiler
//
// Definitions for the uM-FPU V3.1 interface.
//
// @author 	Cam Thompson, Micromega Corporation
// @version
//	February 1, 2008
//	- original code
//=============================================================================

// set assembler constant for CPU frequency
#ifdef F_CPU
  #if F_CPU == 1000000
    #define F_FPU 1000000   
  #elif F_CPU == 1843200
    #define F_FPU 1843200
  #elif F_CPU == 2000000
    #define F_FPU 2000000
  #elif F_CPU == 3686400
    #define F_FPU 3686400
  #elif F_CPU == 4000000
    #define F_FPU 4000000
  #elif F_CPU == 7372800
    #define F_FPU 7372800
  #elif F_CPU == 8000000
    #define F_FPU 8000000
  #elif F_CPU == 11059200
    #define F_FPU 11059200
  #elif F_CPU == 14745600
    #define F_FPU 14745600
  #elif F_CPU == 16000000
    #define F_FPU 16000000
  #elif F_CPU == 18432000
    #define F_FPU 18432000
  #elif F_CPU == 20000000
    #define F_FPU 206000000
  #else
    #error "F_CPU not recognized in fpudefs.h"
  #endif
#endif

#ifndef F_FPU
  #warning "F_FPU set to 16000000"
  #define F_FPU 16000000
#endif

#ifndef	TWCR								// check for I2C hardware
  #error "I2C not supported for selected processor"
#endif

#define RESET_DELAY	(10 * F_FPU / 4000)		// uM-FPU reset delay (10 msec)

#define I2C_ADDR	0xC8					// uM-FPU I2C device address

#define I2C_BITRATE	400000					// set I2C bit rate

#ifdef I2C_BITRATE
  #if (I2C_BITRATE > 400000)				// limit I2C bit rate to 400K
    #undef I2C_BITRATE
	#define I2C_BITRATE	400000
	#warning I2C bit rate set to 400K
  #endif
#else
  #define I2C_BITRATE	100000				// default I2C bit rate is 100K
  #warning I2C bit rate set to 100K
#endif

#define TWBR_VALUE	((F_FPU/I2C_BITRATE)-16)/2
#if (TWBR_VALUE < 0)						// use closest rate attainable
  #undef TWBR_VALUE
  #define TWBR_VALUE	0
  #warning I2C bit rate limited to F_CPU / 16
#endif

#define	rB0	r18								// parameter byte definitions
#define	rB1	r19
#define	rB2	r20
#define	rB3	r21

#define	rA0	r22
#define	rA1	r23
#define	rA2	r24
#define	rA3	r25
