//=============================================================================
// Copyright  Micromega Corporation 2005-2008. All rights reserved.
//
// @file	fpu_spi.h
// @target	Atmel WinAVR C compiler
//
// Definitions for the uM-FPU V3.1 interface.
//
// @author 	Cam Thompson, Micromega Corporation
// @version
//	February 1, 2008
//	- renamed from fpudefs.h to fpu_spi.h
//	- added support for ATmega164P, ATmega324P, ATmega644P, ATmega162
//	January 30, 2008
//	- added support for ATmega64, ATmega128, ATmega48, ATmega88, ATmega168
//	Septemeber 12, 2007
//	- updated for uM-FPU V3.1
//	- support for ATmega8, ATmega16, ATmega32
//	November 15, 2006
//	- original code
//=============================================================================

// set assembler constant for CPU frequency
#ifdef F_CPU
  #if F_CPU == 1000000
    #define F_FPU 1000000   
  #elif F_CPU == 1843200
    #define F_FPU 1843200
  #elif F_CPU == 2000000
    #define F_FPU 2000000
  #elif F_CPU == 3686400
    #define F_FPU 3686400
  #elif F_CPU == 4000000
    #define F_FPU 4000000
  #elif F_CPU == 7372800
    #define F_FPU 7372800
  #elif F_CPU == 8000000
    #define F_FPU 8000000
  #elif F_CPU == 11059200
    #define F_FPU 11059200
  #elif F_CPU == 14745600
    #define F_FPU 14745600
  #elif F_CPU == 16000000
    #define F_FPU 16000000
  #elif F_CPU == 18432000
    #define F_FPU 18432000
  #elif F_CPU == 20000000
    #define F_FPU 206000000
  #else
    #warning "F_CPU not recognized in fpudefs.h"
  #endif
#endif

#ifndef F_FPU
  #warning "F_FPU set to 16000000"
  #define F_FPU 16000000
#endif

//-------------------- SPI port, pin and bit definitions ----------------------

#if defined(_AVR_IOM8_H_) || defined(_AVR_IOMX8_H_)
  // ATmega48, ATmega88, ATmeta168, ATmega 8
  #define SS_PORT	_SFR_IO_ADDR(PORTB)		// *SS is pin PB2
  #define SS_DDR	_SFR_IO_ADDR(DDRB) 
  #define SS_BIT	2
  #define SCK_PORT	_SFR_IO_ADDR(PORTB)		// SCK is pin PB5
  #define SCK_DDR	_SFR_IO_ADDR(DDRB)
  #define SCK_BIT	5
  #define MOSI_PORT	_SFR_IO_ADDR(PORTB)		// MOSI is pin PB3
  #define MOSI_DDR	_SFR_IO_ADDR(DDRB)
  #define MOSI_BIT	3
  #define MISO_PIN	_SFR_IO_ADDR(PINB)		// MISO is pin PB4
  #define MISO_DDR	_SFR_IO_ADDR(DDRB) 
  #define MISO_BIT	4

#elif defined(_AVR_IOM16_H_) || defined(_AVR_IOM32_H_) || defined(_AVR_IOMXX4_H_)|| defined(_AVR_IOM162_H_) 
  // ATmega16, ATmega32, ATmega164P, ATmega324P, ATmega644P, ATmega162
  #define SS_PORT	_SFR_IO_ADDR(PORTB)		// *SS is pin PB4
  #define SS_DDR	_SFR_IO_ADDR(DDRB) 
  #define SS_BIT	4
  #define SCK_PORT	_SFR_IO_ADDR(PORTB)		// SCK is pin PB7
  #define SCK_DDR	_SFR_IO_ADDR(DDRB)
  #define SCK_BIT	7
  #define MOSI_PORT	_SFR_IO_ADDR(PORTB)		// MOSI is pin PB5
  #define MOSI_DDR	_SFR_IO_ADDR(DDRB) 
  #define MOSI_BIT	5
  #define MISO_PIN	_SFR_IO_ADDR(PINB)		// MISO is pin PB6
  #define MISO_DDR	_SFR_IO_ADDR(DDRB) 
  #define MISO_BIT	6

#elif defined(_AVR_IOM64_H_) || defined(_AVR_IOM128_H_)
  // ATmega64, ATmega128
  #define SS_PORT	_SFR_IO_ADDR(PORTB)		// *SS is pin PB0
  #define SS_DDR	_SFR_IO_ADDR(DDRB) 
  #define SS_BIT	0
  #define SCK_PORT	_SFR_IO_ADDR(PORTB)		// SCK is pin PB1
  #define SCK_DDR	_SFR_IO_ADDR(DDRB)
  #define SCK_BIT	1
  #define MOSI_PORT	_SFR_IO_ADDR(PORTB)		// MOSI is pin PB2
  #define MOSI_DDR	_SFR_IO_ADDR(DDRB) 
  #define MOSI_BIT	2
  #define MISO_PIN	_SFR_IO_ADDR(PINB)		// MISO is pin PB3
  #define MISO_DDR	_SFR_IO_ADDR(DDRB) 
  #define MISO_BIT	3

#else
  #warning "fpudef.h symbols not defined for selected processor"
#endif

// to enable FPU CS, add -DFPU_CS_ENABLED=1 to Project Custom Options,
// or uncomment the following definition.
//#define FPU_CS_ENABLED 1

#ifdef FPU_CS_ENABLED
  #define	FPU_CS_PORT	SS_PORT				// *SS is used as FPU CS
  #define	FPU_CS_DDR	SS_DDR
  #define	FPU_CS_BIT	SS_BIT
#endif

#define _SPCR	_SFR_IO_ADDR(SPCR)			// SPI registers
#define _SPSR	_SFR_IO_ADDR(SPSR)
#define _SPDR	_SFR_IO_ADDR(SPDR)

#define RESET_DELAY	(10 * F_FPU / 4000)		// 10 msec
#define READ_DELAY	(15 * F_FPU / 3000000)	// 15 usec
#define WAIT_DELAY	(F_FPU / 3000000)		// 1 usec

#define	rB0	r18								// parameter byte definitions
#define	rB1	r19
#define	rB2	r20
#define	rB3	r21

#define	rA0	r22
#define	rA1	r23
#define	rA2	r24
#define	rA3	r25
